@@ -37,8 +37,6 @@
 #include "introspection.h"
 #include "object.h"
 
-#define MAX_CHILDREN 65536
-
 typedef struct _MatchRulePrivate MatchRulePrivate;
 struct _MatchRulePrivate
 {
@@ -73,7 +71,7 @@ child_interface_p (AtkObject *child, gchar *repo_id)
       p = strchr (repo_id, '(');
       if (!p)
         return FALSE;
-      strncpy (name, p + 1, sizeof (name) - 1);
+      strncpy (name, p + 1, sizeof (name));
       name[sizeof (name) - 1] = '\0';
       p = strchr (name, ')');
       if (p)
@@ -509,14 +507,14 @@ traverse_p (AtkObject *child, const gboolean traverse)
 }
 
 static int
-sort_order_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gint max, AtkObject *obj, glong index, gboolean flag, AtkObject *pobj, gboolean recurse, gboolean traverse)
+sort_order_canonical (MatchRulePrivate *mrp, GList *ls, gint kount, gint max, AtkObject *obj, glong index, gboolean flag, AtkObject *pobj, gboolean recurse, gboolean traverse)
 {
   gint i = index;
   glong acount = atk_object_get_n_accessible_children (obj);
   gboolean prev = pobj ? TRUE : FALSE;
 
-  if (acount > MAX_CHILDREN)
-    acount = MAX_CHILDREN;
+  if (acount > ATSPI_MAX_CHILDREN)
+    acount = ATSPI_MAX_CHILDREN;
   for (; i < acount && (max == 0 || kount < max); i++)
     {
       AtkObject *child = atk_object_ref_accessible_child (obj, i);
@@ -533,7 +531,7 @@ sort_order_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gint ma
       if (flag && match_interfaces_lookup (child, mrp) && match_states_lookup (child, mrp) && match_roles_lookup (child, mrp) && match_attributes_lookup (child, mrp))
         {
 
-          g_ptr_array_add (arr, g_object_ref (child));
+          ls = g_list_append (ls, child);
           kount++;
         }
 
@@ -541,7 +539,7 @@ sort_order_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gint ma
         flag = TRUE;
 
       if (recurse && traverse_p (child, traverse))
-        kount = sort_order_canonical (mrp, arr, kount,
+        kount = sort_order_canonical (mrp, ls, kount,
                                       max, child, 0, TRUE,
                                       pobj, recurse, traverse);
       g_object_unref (child);
@@ -550,7 +548,7 @@ sort_order_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gint ma
 }
 
 static int
-sort_order_rev_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gint max, AtkObject *obj, gboolean flag, AtkObject *pobj)
+sort_order_rev_canonical (MatchRulePrivate *mrp, GList *ls, gint kount, gint max, AtkObject *obj, gboolean flag, AtkObject *pobj)
 {
   AtkObject *nextobj;
   AtkObject *parent;
@@ -565,7 +563,7 @@ sort_order_rev_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gin
   /* Add to the list if it matches */
   if (flag && match_interfaces_lookup (obj, mrp) && match_states_lookup (obj, mrp) && match_roles_lookup (obj, mrp) && match_attributes_lookup (obj, mrp) && (max == 0 || kount < max))
     {
-      g_ptr_array_add (arr, g_object_ref (obj));
+      ls = g_list_append (ls, obj);
       kount++;
     }
 
@@ -585,15 +583,15 @@ sort_order_rev_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gin
         {
           AtkObject *follow;
           gint count = atk_object_get_n_accessible_children (nextobj);
-          if (count > MAX_CHILDREN)
-            count = MAX_CHILDREN;
+          if (count > ATSPI_MAX_CHILDREN)
+            count = ATSPI_MAX_CHILDREN;
 
           follow = atk_object_ref_accessible_child (nextobj, count - 1);
           g_object_unref (nextobj);
           nextobj = follow;
         }
       /* recurse with the last descendant */
-      kount = sort_order_rev_canonical (mrp, arr, kount, max,
+      kount = sort_order_rev_canonical (mrp, ls, kount, max,
                                         nextobj, TRUE, pobj);
       if (nextobj)
         g_object_unref (nextobj);
@@ -601,23 +599,23 @@ sort_order_rev_canonical (MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gin
   else if (max == 0 || kount < max)
     {
       /* no more siblings so next node must be the parent */
-      kount = sort_order_rev_canonical (mrp, arr, kount, max,
+      kount = sort_order_rev_canonical (mrp, ls, kount, max,
                                         parent, TRUE, pobj);
     }
   return kount;
 }
 
 static int
-query_exec (MatchRulePrivate *mrp, AtspiCollectionSortOrder sortby, GPtrArray *arr, gint kount, gint max, AtkObject *obj, glong index, gboolean flag, AtkObject *pobj, gboolean recurse, gboolean traverse)
+query_exec (MatchRulePrivate *mrp, AtspiCollectionSortOrder sortby, GList *ls, gint kount, gint max, AtkObject *obj, glong index, gboolean flag, AtkObject *pobj, gboolean recurse, gboolean traverse)
 {
   switch (sortby)
     {
     case ATSPI_Collection_SORT_ORDER_CANONICAL:
-      kount = sort_order_canonical (mrp, arr, 0, max, obj, index, flag,
+      kount = sort_order_canonical (mrp, ls, 0, max, obj, index, flag,
                                     pobj, recurse, traverse);
       break;
     case ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL:
-      kount = sort_order_canonical (mrp, arr, 0, max, obj, index, flag,
+      kount = sort_order_canonical (mrp, ls, 0, max, obj, index, flag,
                                     pobj, recurse, traverse);
       break;
     default:
@@ -763,11 +761,11 @@ read_mr (DBusMessageIter *iter, MatchRulePrivate *mrp)
 }
 
 static DBusMessage *
-return_and_free_array (DBusMessage *message, GPtrArray *arr, gboolean reverse_order)
+return_and_free_list (DBusMessage *message, GList *ls)
 {
   DBusMessage *reply;
   DBusMessageIter iter, iter_array;
-  guint ii;
+  GList *item;
 
   reply = dbus_message_new_method_return (message);
   if (!reply)
@@ -775,18 +773,17 @@ return_and_free_array (DBusMessage *message, GPtrArray *arr, gboolean reverse_or
   dbus_message_iter_init_append (reply, &iter);
   if (!dbus_message_iter_open_container (&iter, DBUS_TYPE_ARRAY, "(so)", &iter_array))
     goto oom;
-  for (ii = 0; ii < arr->len; ii++)
+  for (item = ls; item; item = g_list_next (item))
     {
-      AtkObject *obj = ATK_OBJECT (g_ptr_array_index (arr, reverse_order ? arr->len - ii - 1 : ii));
-      spi_object_append_reference (&iter_array, obj);
+      spi_object_append_reference (&iter_array, ATK_OBJECT (item->data));
     }
   if (!dbus_message_iter_close_container (&iter, &iter_array))
     goto oom;
-  g_ptr_array_unref (arr);
+  g_list_free (ls);
   return reply;
 oom:
   // TODO: Handle out of memory
-  g_ptr_array_unref (arr);
+  g_list_free (ls);
   return reply;
 }
 
@@ -808,24 +805,29 @@ GetMatchesFrom (DBusMessage *message,
                 dbus_int32_t count,
                 const dbus_bool_t traverse)
 {
-  GPtrArray *arr;
+  GList *ls = NULL;
   AtkObject *parent;
   glong index = atk_object_get_index_in_parent (current_object);
 
-  arr = g_ptr_array_new_with_free_func (g_object_unref);
+  ls = g_list_append (ls, current_object);
 
   if (!isrestrict)
     {
       parent = atk_object_get_parent (current_object);
-      query_exec (mrp, sortby, arr, 0, count, parent, index,
+      query_exec (mrp, sortby, ls, 0, count, parent, index,
                   FALSE, NULL, TRUE, traverse);
     }
   else
-    query_exec (mrp, sortby, arr, 0, count,
+    query_exec (mrp, sortby, ls, 0, count,
                 current_object, 0, FALSE, NULL, TRUE, traverse);
 
+  ls = g_list_remove (ls, ls->data);
+
+  if (sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL)
+    ls = g_list_reverse (ls);
+
   free_mrp_data (mrp);
-  return return_and_free_array (message, arr, sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL);
+  return return_and_free_list (message, ls);
 }
 
 /*
@@ -833,12 +835,12 @@ GetMatchesFrom (DBusMessage *message,
 */
 
 static int
-inorder (AtkObject *collection, MatchRulePrivate *mrp, GPtrArray *arr, gint kount, gint max, AtkObject *obj, gboolean flag, AtkObject *pobj, dbus_bool_t traverse)
+inorder (AtkObject *collection, MatchRulePrivate *mrp, GList *ls, gint kount, gint max, AtkObject *obj, gboolean flag, AtkObject *pobj, dbus_bool_t traverse)
 {
   int i = 0;
 
   /* First, look through the children recursively. */
-  kount = sort_order_canonical (mrp, arr, kount, max, obj, 0, TRUE,
+  kount = sort_order_canonical (mrp, ls, kount, max, obj, 0, TRUE,
                                 NULL, TRUE, TRUE);
 
   /* Next, we look through the right subtree */
@@ -846,7 +848,7 @@ inorder (AtkObject *collection, MatchRulePrivate *mrp, GPtrArray *arr, gint koun
     {
       AtkObject *parent = atk_object_get_parent (obj);
       i = atk_object_get_index_in_parent (obj);
-      kount = sort_order_canonical (mrp, arr, kount, max, parent,
+      kount = sort_order_canonical (mrp, ls, kount, max, parent,
                                     i + 1, TRUE, FALSE, TRUE, TRUE);
       obj = parent;
     }
@@ -867,18 +869,23 @@ GetMatchesInOrder (DBusMessage *message,
                    dbus_int32_t count,
                    const dbus_bool_t traverse)
 {
-  GPtrArray *arr;
+  GList *ls = NULL;
   AtkObject *obj;
 
-  arr = g_ptr_array_new_with_free_func (g_object_unref);
+  ls = g_list_append (ls, current_object);
 
   obj = ATK_OBJECT (spi_register_path_to_object (spi_global_register, dbus_message_get_path (message)));
 
-  inorder (obj, mrp, arr, 0, count,
+  inorder (obj, mrp, ls, 0, count,
            current_object, TRUE, NULL, traverse);
 
+  ls = g_list_remove (ls, ls->data);
+
+  if (sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL)
+    ls = g_list_reverse (ls);
+
   free_mrp_data (mrp);
-  return return_and_free_array (message, arr, sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL);
+  return return_and_free_list (message, ls);
 }
 
 /*
@@ -893,18 +900,23 @@ GetMatchesInBackOrder (DBusMessage *message,
                        const AtspiCollectionSortOrder sortby,
                        dbus_int32_t count)
 {
-  GPtrArray *arr;
+  GList *ls = NULL;
   AtkObject *collection;
 
-  arr = g_ptr_array_new_with_free_func (g_object_unref);
+  ls = g_list_append (ls, current_object);
 
   collection = ATK_OBJECT (spi_register_path_to_object (spi_global_register, dbus_message_get_path (message)));
 
-  sort_order_rev_canonical (mrp, arr, 0, count, current_object,
+  sort_order_rev_canonical (mrp, ls, 0, count, current_object,
                             FALSE, collection);
 
+  ls = g_list_remove (ls, ls->data);
+
+  if (sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL)
+    ls = g_list_reverse (ls);
+
   free_mrp_data (mrp);
-  return return_and_free_array (message, arr, sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL);
+  return return_and_free_list (message, ls);
 }
 
 static DBusMessage *
@@ -917,26 +929,30 @@ GetMatchesTo (DBusMessage *message,
               dbus_int32_t count,
               const dbus_bool_t traverse)
 {
-  GPtrArray *arr;
+  GList *ls = NULL;
   AtkObject *obj;
-
-  arr = g_ptr_array_new_with_free_func (g_object_unref);
+  ls = g_list_append (ls, current_object);
 
   if (recurse)
     {
       obj = ATK_OBJECT (atk_object_get_parent (current_object));
-      query_exec (mrp, sortby, arr, 0, count,
+      query_exec (mrp, sortby, ls, 0, count,
                   obj, 0, TRUE, current_object, TRUE, traverse);
     }
   else
     {
       obj = ATK_OBJECT (spi_register_path_to_object (spi_global_register, dbus_message_get_path (message)));
-      query_exec (mrp, sortby, arr, 0, count,
+      query_exec (mrp, sortby, ls, 0, count,
                   obj, 0, TRUE, current_object, TRUE, traverse);
     }
 
+  ls = g_list_remove (ls, ls->data);
+
+  if (sortby != ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL)
+    ls = g_list_reverse (ls);
+
   free_mrp_data (mrp);
-  return return_and_free_array (message, arr, sortby != ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL);
+  return return_and_free_list (message, ls);
 }
 
 static DBusMessage *
@@ -995,7 +1011,6 @@ impl_GetMatchesFrom (DBusConnection *bus, DBusMessage *message, void *user_data)
                                 &rule, sortby, TRUE, count, traverse);
       break;
     default:
-      free_mrp_data (&rule);
       return NULL;
     }
 }
@@ -1059,7 +1074,6 @@ impl_GetMatchesTo (DBusConnection *bus, DBusMessage *message, void *user_data)
                                     &rule, sortby, count);
       break;
     default:
-      free_mrp_data (&rule);
       return NULL;
     }
 }
@@ -1136,8 +1150,8 @@ append_accessible_properties (DBusMessageIter *iter, AtkObject *obj, GArray *pro
         return;
     }
   count = atk_object_get_n_accessible_children (obj);
-  if (count > MAX_CHILDREN)
-    count = MAX_CHILDREN;
+  if (count > ATSPI_MAX_CHILDREN)
+    count = ATSPI_MAX_CHILDREN;
   for (i = 0; i < count; i++)
     {
       AtkObject *child = atk_object_ref_accessible_child (obj, i);
@@ -1191,7 +1205,6 @@ impl_GetTree (DBusConnection *bus,
       append_accessible_properties (&iter_array, object, properties);
       dbus_message_iter_close_container (&iter, &iter_array);
     }
-  free_mrp_data (&rule);
   return reply;
 }
 
@@ -1204,7 +1217,7 @@ impl_GetMatches (DBusConnection *bus, DBusMessage *message, void *user_data)
   dbus_uint32_t sortby;
   dbus_int32_t count;
   dbus_bool_t traverse;
-  GPtrArray *arr;
+  GList *ls = NULL;
   const char *signature;
 
   signature = dbus_message_get_signature (message);
@@ -1224,12 +1237,15 @@ impl_GetMatches (DBusConnection *bus, DBusMessage *message, void *user_data)
   dbus_message_iter_next (&iter);
   dbus_message_iter_get_basic (&iter, &traverse);
   dbus_message_iter_next (&iter);
-  arr = g_ptr_array_new_with_free_func (g_object_unref);
-  count = query_exec (&rule, sortby, arr, 0, count,
+  ls = g_list_prepend (ls, obj);
+  count = query_exec (&rule, sortby, ls, 0, count,
                       obj, 0, TRUE, NULL, TRUE, traverse);
+  ls = g_list_remove (ls, ls->data);
 
+  if (sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL)
+    ls = g_list_reverse (ls);
   free_mrp_data (&rule);
-  return return_and_free_array (message, arr, sortby == ATSPI_Collection_SORT_ORDER_REVERSE_CANONICAL);
+  return return_and_free_list (message, ls);
 }
 
 static DRouteMethod methods[] = {
