@@ -512,10 +512,14 @@ static AtkSocketClass *socket_class;
 static gchar *
 get_plug_id (AtkPlug *plug)
 {
-  const char *uname = dbus_bus_get_unique_name (spi_global_app_data->bus);
+  const char *uname;
   gchar *path;
   GString *str = g_string_new (NULL);
 
+  if (!spi_global_app_data || !spi_global_app_data->bus)
+    return NULL;
+
+  uname = dbus_bus_get_unique_name (spi_global_app_data->bus);
   path = spi_register_object_to_path (spi_global_register, G_OBJECT (plug));
   g_string_printf (str, "%s:%s", uname, path);
   g_free (path);
@@ -1278,18 +1282,20 @@ atk_bridge_adaptor_init (gint *argc, gchar **argv[])
   atexit_added = TRUE;
 
   spi_global_app_data->session_bus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
-  g_assert (spi_global_app_data->session_bus);
-  spi_global_app_data->name_owner_changed_subscription_id =
-      g_dbus_connection_signal_subscribe (spi_global_app_data->session_bus,
-                                          "org.freedesktop.DBus",  /* name */
-                                          "org.freedesktop.DBus",  /* interface */
-                                          "NameOwnerChanged",      /* signal name */
-                                          "/org/freedesktop/DBus", /* path */
-                                          "org.a11y.Bus",          /* arg0 */
-                                          G_DBUS_SIGNAL_FLAGS_NONE,
-                                          on_session_name_owner_changed,
-                                          NULL,
-                                          (GDestroyNotify) NULL);
+  if (spi_global_app_data->session_bus)
+    {
+      spi_global_app_data->name_owner_changed_subscription_id =
+          g_dbus_connection_signal_subscribe (spi_global_app_data->session_bus,
+                                              "org.freedesktop.DBus",  /* name */
+                                              "org.freedesktop.DBus",  /* interface */
+                                              "NameOwnerChanged",      /* signal name */
+                                              "/org/freedesktop/DBus", /* path */
+                                              "org.a11y.Bus",          /* arg0 */
+                                              G_DBUS_SIGNAL_FLAGS_NONE,
+                                              on_session_name_owner_changed,
+                                              NULL,
+                                              (GDestroyNotify) NULL);
+    }
 
   return 0;
 }
