@@ -84,8 +84,8 @@
 
  */
 
-#ifndef _ATSPI_CONSTANTS_H_
-#define _ATSPI_CONSTANTS_H_
+#pragma once
+
 /**
  * AtspiConstants:
  *
@@ -1535,7 +1535,12 @@ extern "C"
 #define ATSPI_DBUS_PATH_SCREEN_READER "/org/a11y/atspi/screenreader"
 #define ATSPI_DBUS_INTERFACE_EVENT_SCREEN_READER "org.a11y.atspi.Event.ScreenReader"
 
+#define ATSPI_DBUS_INTERFACE_KEYBOARD_MONITOR "org.freedesktop.a11y.KeyboardMonitor"
+#define ATSPI_DBUS_NAME_A11Y_MANAGER "org.freedesktop.a11y.Manager"
+#define ATSPI_DBUS_PATH_A11Y_MANAGER "/org/freedesktop/a11y/Manager"
+
+#define ATSPI_MAX_CHILDREN 65536
+
 #ifdef __cplusplus
 }
 #endif
-#endif /* _ATSPI_CONSTANTS_H_ */
