@@ -27,13 +27,13 @@ static void
 atk_test_hyperlink_get_n_anchors (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   gint n = atspi_hyperlink_get_n_anchors (obj, NULL);
   g_assert_cmpint (n, ==, 1);
   g_object_unref (obj);
@@ -45,15 +45,15 @@ static void
 atk_test_hyperlink_get_uri (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   gchar *str = atspi_hyperlink_get_uri (obj, 0, NULL);
-  g_assert (str);
+  g_assert_nonnull (str);
   g_assert_cmpstr (str, ==, "pinkbike.com");
   g_free (str);
   g_object_unref (obj);
@@ -65,17 +65,17 @@ static void
 atk_test_hyperlink_get_object (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   AtspiAccessible *acc = atspi_hyperlink_get_object (obj, 0, NULL);
-  g_assert (acc);
+  g_assert_nonnull (acc);
   AtspiText *at = atspi_accessible_get_text_iface (acc);
-  g_assert (at);
+  g_assert_nonnull (at);
   gchar *text = atspi_text_get_text (at, 0, 12, NULL);
   g_assert_cmpstr (text, ==, "pinkbike.com");
   g_free (text);
@@ -90,15 +90,15 @@ static void
 atk_test_hyperlink_get_index_range (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   AtspiRange *range = atspi_hyperlink_get_index_range (obj, NULL);
-  g_assert (range);
+  g_assert_nonnull (range);
   /*
     ATK do not define this function
   */
@@ -114,13 +114,13 @@ static void
 atk_test_hyperlink_get_start_index (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   gint n = atspi_hyperlink_get_start_index (obj, NULL);
   g_assert_cmpint (n, ==, 69);
   g_object_unref (obj);
@@ -132,13 +132,13 @@ static void
 atk_test_hyperlink_get_end_index (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
+  g_assert_nonnull (obj);
   gint n = atspi_hyperlink_get_end_index (obj, NULL);
   g_assert_cmpint (n, ==, 81);
   g_object_unref (obj);
@@ -150,14 +150,14 @@ static void
 atk_test_hyperlink_is_valid (TestAppFixture *fixture, gconstpointer user_data)
 {
   AtspiAccessible *_obj = fixture->root_obj;
-  g_assert (_obj);
+  g_assert_nonnull (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
-  g_assert (child);
+  g_assert_nonnull (child);
   AtspiHypertext *obj1 = atspi_accessible_get_hypertext_iface (child);
-  g_assert (obj1);
+  g_assert_nonnull (obj1);
   AtspiHyperlink *obj = atspi_hypertext_get_link (obj1, 1, NULL);
-  g_assert (obj);
-  g_assert (atspi_hyperlink_is_valid (obj, NULL));
+  g_assert_nonnull (obj);
+  g_assert_true (atspi_hyperlink_is_valid (obj, NULL));
   g_object_unref (obj);
   g_object_unref (obj1);
   g_object_unref (child);
